float4x4 wvp : WorldViewProjection;
float4x4 world : World;
float4x4 worldI : WorldI;
float4x4 viewI : ViewI;

struct appdata {
    float4 Position	 : POSITION;
    float4 texcoord0     : TEXCOORD0;
    float4 Normal	 : NORMAL;
};

struct vertexOutput {
    float4 Position  	 : POSITION;
    float4 texcoord0	 : TEXCOORD0;
    float4 texcoord1     : TEXCOORD1;
    float4 texcoord2	 : TEXCOORD2;
    float4 texcoord3	 : TEXCOORD3;
    float4 texcoord4	 : TEXCOORD4;
};

struct pixelOutput {
  float4 col : COLOR;
};

vertexOutput mainVS(appdata IN,
    uniform float4x4 WorldViewProj,
    uniform float4x4 World,
    uniform float4x4 WorldI,
    uniform float4x4 ViewI
) 
{
    vertexOutput OUT;

    OUT.Position = mul(WorldViewProj, IN.Position);
    OUT.texcoord0 = IN.texcoord0;

    OUT.texcoord1.xyz = mul(ViewI, float4(0.0, 0.0, 0.0, 1.0)).xyz;
    OUT.texcoord2.xyz = mul(World, IN.Position).xyz;
    OUT.texcoord3.xyz = mul(IN.Normal, WorldI).xyz;

    return OUT;
}


pixelOutput mainPS(vertexOutput IN,
    uniform samplerCUBE EnvironmentMap)
{
    pixelOutput OUT; 

    float3 normal       = IN.texcoord3.xyz;
    float3 viewVector   = IN.texcoord2.xyz - IN.texcoord1.xyz;
    
    float3 reflVect = reflect(viewVector, normal);
    float4 reflColor = texCUBE(EnvironmentMap, reflVect);

    OUT.col = reflColor;

    return OUT;
}

texture cubeMap : EnvMap
<
    string File = "nvlobby_new.dds";
    string TextureType = "Cube";
>;

samplerCUBE environmentMapSampler = sampler_state
{
	Texture = <cubeMap>;

	MinFilter = Linear;
	MagFilter = Linear;
	MipFilter = Linear;

      AddressU  = Clamp;
      AddressV  = Clamp;
      AddressW  = Clamp;
};

technique dx9textured
{
	pass p0 
	{		
                VertexShader = compile vs_2_0 mainVS(wvp, world, worldI, viewI);

		ZEnable = true;
		ZWriteEnable = true;
		CullMode = CW;
                //CullMode = None;

                PixelShader = compile ps_2_0 mainPS(environmentMapSampler);
	}
}
