#pragma once

#include "nvutil/Assert.h"

#if defined(_WIN32) // _WIN32 is defined for both win32 and win64

// 64-bit CString has no GetString member, but implicit conversion to LPCTSTR 
inline LPCTSTR GetString(const CString& cstr)
{
#if !defined(_WIN64)
  return cstr.GetString();
#else
  return cstr;
#endif
}

// 64-bit CString has no Tokenize member
inline CString Tokenize(const CString& cstr, const char * pszTokens, int& iStart)
{
#if !defined(_WIN64)
  return cstr.Tokenize(pszTokens, iStart);
#else
		__ASSERT(iStart >= 0);
			
    CString ret("");

		if( pszTokens == NULL )
		{
			return( cstr );
		}

    // copy input string to generic char array
    char * str = new char[cstr.GetLength()+1];
    strcpy(str, (LPCTSTR)cstr);

		char * start = str+iStart;
		char * end = str+strlen(str);
    char * token = NULL;

		if (  start < end 
       && (token = strtok(start, pszTokens)) 
       )
		{
      ret = token;
      char * next = strtok(NULL, pszTokens);
      iStart += next ? int(next-start) : int(end-start+1);
    }
    else
    {
      // done
		  iStart = -1;
    }
    delete[] str;
    return ret;
#endif
}

// 64-bit version of CString::MakeLower returns 'void' and not 'CString&'
inline CString& MakeLower(CString& cstr)
{
#if !defined(_WIN64)
  return cstr.MakeLower();
#else
  cstr.MakeLower();
  return cstr;
#endif
}

#endif