// Copyright NVIDIA Corporation 2002-2004
// TO THE MAXIMUM EXTENT PERMITTED BY APPLICABLE LAW, THIS SOFTWARE IS PROVIDED
// *AS IS* AND NVIDIA AND ITS SUPPLIERS DISCLAIM ALL WARRANTIES, EITHER EXPRESS
// OR IMPLIED, INCLUDING, BUT NOT LIMITED TO, IMPLIED WARRANTIES OF MERCHANTABILITY
// AND FITNESS FOR A PARTICULAR PURPOSE.  IN NO EVENT SHALL NVIDIA OR ITS SUPPLIERS
// BE LIABLE FOR ANY SPECIAL, INCIDENTAL, INDIRECT, OR CONSEQUENTIAL DAMAGES
// WHATSOEVER (INCLUDING, WITHOUT LIMITATION, DAMAGES FOR LOSS OF BUSINESS PROFITS,
// BUSINESS INTERRUPTION, LOSS OF BUSINESS INFORMATION, OR ANY OTHER PECUNIARY LOSS)
// ARISING OUT OF THE USE OF OR INABILITY TO USE THIS SOFTWARE, EVEN IF NVIDIA HAS
// BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES 

#pragma once
/** @file */

#include "nvsgcommon.h"

#include "nvsg/LightSource.h"
#include "nvmath/Vec3f.h"

namespace nvsg
{
  //! Class representing a directed light
  /** Directed light is just that - directed. Directed light always has direction and color, and is a factor in 
    * shading algorithms such as Gouraud shading.
    * \note
    * The default light direction is (0,0,-1).
    */
  class DirectedLight : public LightSource
  {
    public:
      //! Create a DirectedLight.
      /** \returns a constant pointer to a DirectedLight. */
      NVSG_API static const DirectedLight * create( void );

      //! Create a DirectedLight by copying from a LightSource.
      /** \returns a constant pointer to a DirectedLight. */
      NVSG_API static const DirectedLight * createFromBase( const LightSource &rhs  //!< LightSource to copy from
                                                          );

      //! Get a clone of this DirectedLight.
      /** \returns A constant pointer to the new created clone. */
      NVSG_API virtual const DirectedLight * clone( void ) const;

      //--  Functions reimplemented from Object  --
      NVSG_API virtual DataID getDataID( void ) const;
      NVSG_API virtual bool isDataShared( void ) const;

    protected:
      //! Default Constructor
      NVSG_API DirectedLight( void );

      //! Partial Constructor
      NVSG_API DirectedLight( const LightSource &rhs );

      //! Copy Constructor
      NVSG_API DirectedLight( const DirectedLight &rhs );

      //! Protected destructor to prevent explicit creation on stack.
      NVSG_API virtual ~DirectedLight(void);
  };

} //  namespace nvsg
